@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010001;
 
-our $VERSION = '0.29';
+our $VERSION = '0.30';
 
 use Carp;
 use JSON qw(decode_json);
@@ -23,6 +23,7 @@ my $PANDOC_BIN_MIN = Pandoc::Version->new('1.12.1');
 
 # release version => minimal required api version
 my @REQUIRED_API = map { Pandoc::Version->new($_) }
+    '1.19'   => '1.17',  # pandoc 1.19 has api 1.17.0.4, compatible with api 1.17
     '1.18'   => '1.17',  # pandoc 1.18 has api 1.17.0.4, compatible with api 1.17
     '1.16'   => '1.16',  # pandoc 1.16 has api 1.16
     '1.17'   => '1.16',  # pandoc 1.17 has api 1.16
@@ -42,7 +43,7 @@ sub pandoc_version {
                     // croak "pandoc version not supported"
             );
         }
-        _minimum_api_version_for($doc->api_version);
+        _minimum_pandoc_version_for_api($doc->api_version);
     } elsif (defined $PANDOC_VERSION) {
         _as_pandoc_version($PANDOC_VERSION)
     } else {
@@ -50,16 +51,24 @@ sub pandoc_version {
     }
 }
 
-sub _minimum_api_version_for {
-    my $api_version = shift;
+sub _minimum_pandoc_version_for_api {
+    my $api = shift;
+
+    my $version;
 
     foreach (grep { $_ % 2} 0 .. @REQUIRED_API) { # 1,3,...
-        if ($api_version->match($REQUIRED_API[$_]) ) {
-            return $REQUIRED_API[$_-1]
+        if ($api->match($REQUIRED_API[$_]) ) {
+            if (!$version or $version > $REQUIRED_API[$_-1]) {
+                $version = $REQUIRED_API[$_-1]
+            }
         }
     }
 
-    return $api_version >= $PANDOC_API_MIN ? $PANDOC_BIN_MIN : undef;
+    if (!$version and $api >= $PANDOC_API_MIN) {
+        $PANDOC_BIN_MIN;
+    } else {
+        return $version;
+    }
 }
 
 sub _minimum_pandoc_api_for {
@@ -68,10 +77,16 @@ sub _minimum_pandoc_api_for {
 
     foreach (grep { $_ % 2} 0 .. @REQUIRED_API) { # 1,3,...
         if ($version->match($REQUIRED_API[$_-1]) ) {
-            return $REQUIRED_API[$_]
+            return $REQUIRED_API[$_];
         }
     }
 
+    # required version is newer than any known version
+    # return the latest known api version and hope it has not changed
+    if ($version > $REQUIRED_API[0]) {
+        return $REQUIRED_API[1];
+    }
+
     return $version >= $PANDOC_BIN_MIN ? $PANDOC_API_MIN : undef;
 }
 
@@ -319,6 +334,7 @@ sub pandoc_json($) {
     package Pandoc::Document;
     use strict;
     use Carp 'croak';
+    use Scalar::Util qw(blessed);
     use Pandoc;
     our $VERSION = '0.04';
     our @ISA = ('Pandoc::Document::Element');
@@ -335,8 +351,12 @@ sub pandoc_json($) {
     *blocks = \&content;
     sub is_document { 1 }
     sub metavalue {
-        my $meta = $_[0]->meta;
-        return { map { $_ => $meta->{$_}->metavalue } keys %$meta }
+        my $meta = shift->meta;
+        if (@_) {
+            return $meta->{$_[0]} ? $meta->{$_[0]}->metavalue : undef;
+        } else {
+            return { map { $_ => $meta->{$_}->metavalue } keys %$meta }
+        }
     }
     sub string {
         join '', map { $_->string } @{$_[0]->content}
@@ -393,8 +413,15 @@ sub pandoc_json($) {
     }
     sub to_pandoc {
         my ($self, @args) = @_;
-        my $pandoc = pandoc;
+        my $pandoc = (@_ and blessed($_[0]) and $_[0]->isa('Pandoc'))
+                   ? shift : pandoc;
+
+        my $api_version = $self->api_version;   # save
+        $self->pandoc_version( $pandoc->version );
+
         my $in = $self->to_json;
+        $self->api_version($api_version);       # restore
+
         $pandoc->run( [ -f => 'json', @args ], { in => \$in, out => \my $out } );
         return $out;
     }
@@ -1142,21 +1169,30 @@ document.
 
 Return document L<metadata elements|/METADATA ELEMENTS>.
 
-=item B<metavalue>
+=item B<metavalue( [ $field ] )>
 
-Returns a copy of the metadata hash with all L<metadata elements|/METADATA
-ELEMENTS> flattened to unblessed values:
+Called without an argument this method returns a copy of the metadata hash with
+all L<metadata elements|/METADATA ELEMENTS> flattened to unblessed values:
 
     $doc->metavalue   # equivalent to
     { map { $_ => $doc->meta->{$_}->metavalue } keys %{$doc->meta} }
 
-=item B<to_pandoc( [ @arguments ])>
+Called with a field, this method is a shortcut for
+
+    $doc->meta->{$field}->metavalue
+
+or C<undef> if the given field does not exist.
+
+=item B<to_pandoc( [ [ $pandoc, ] @arguments ])>
 
 Process the document with L<Pandoc> executable and return its output:
 
     $doc->to_pandoc( -o => 'doc.html' );
     my $markdown = $doc->to_pandoc( -t => 'markdown' );
 
+The first argument can optionally be an instance of L<Pandoc> to use a specific
+executable.
+
 =item B<to_...( [ @arguments ] )>
 
 Process the document into C<markdown> (pandoc's extended Markdown), C<latex>
